pub enum StateRecord {
Account {
account_id: AccountId,
account: Value,
},
Data {
account_id: AccountId,
data_key_base64: String,
value_base64: String,
},
Contract {
account_id: AccountId,
code_base64: String,
},
AccessKey {
account_id: AccountId,
public_key_base64: String,
access_key: Value,
},
PostponedReceipt(Value),
ReceivedData {
account_id: AccountId,
data_id_hash: String,
data_base64: Option<String>,
},
DelayedReceipt(Value),
}Expand description
We don’t want to introduce extra dependencies to the crate so we use serde_json::Value to represent more complex types.
Though we still want to have at least some type safety.
Variants